from bs4 import BeautifulSoup
import requests as rq 
import pandas as pd

def get_current_price(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS"
    html = rq.get(url).text    
    soup = BeautifulSoup(html,"lxml")
    price1 = soup.find("div",id="quote-header-info")
    price2 = price1.find("span", class_ ="Trsdu(0.3s) Fw(b) Fz(36px) Mb(-4px) D(ib)")
    price3 = price2.text
    price = price3.replace(",","")

    return float(price)

def get_stock_volume(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS"
    data = pd.read_html(url)
    volume = data[0].at[6,1]
    volume = volume.replace(",","")

    return float(volume)





from Stock_Data_Srapes.price_data import get_current_price
from Stock_Data_Srapes.price_data import get_stock_volume

from Stock_Data_Srapes.financial_data import T_M_B_converter
from Stock_Data_Srapes.financial_data import get_market_cap
from Stock_Data_Srapes.financial_data import get_Earnings_Per_Share
from Stock_Data_Srapes.financial_data import get_average_stock_volume
from Stock_Data_Srapes.financial_data import get_enterprise_value
from Stock_Data_Srapes.financial_data import get_price_to_sales_ratio
from Stock_Data_Srapes.financial_data import get_price_to_book_ratio



from bs4 import BeautifulSoup
import requests as rq 
import pandas as pd

def T_M_B_converter(elemment):
    if "T" in elemment:
        elemment = elemment.replace("T","")
        elemment = elemment.replace(",","")
        elemment = float(elemment) * 1000000000000
    else:
        if "B" in elemment:
            elemment = elemment.replace("B","")
            elemment = elemment.replace(",","")
            elemment = float(elemment) * 1000000000
        else:
            if "M" in elemment:
                elemment = elemment.replace("M","")
                elemment = elemment.replace(",","")
                elemment = float(elemment) * 1000000
            else:
                print("Error - in value")

    return float(elemment)

def get_market_cap(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS"
    data = pd.read_html(url)
    market_cap = data[1].at[0,1]
    market_cap = T_M_B_converter(market_cap)

    return float(market_cap)

def get_Earnings_Per_Share(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS"
    data = pd.read_html(url)
    earnings_per_share = data[1].at[3,1]
    earnings_per_share = earnings_per_share.replace(",","")

    return float(earnings_per_share)

def get_average_stock_volume(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS"
    data = pd.read_html(url)
    avg_volume = data[0].at[7,1]
    avg_volume = avg_volume.replace(",","")

    return float(avg_volume)

def get_enterprise_value(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS/key-statistics"
    data = pd.read_html(url)
    enterprice_value = data[0].at[1,1]
    enterprice_value = T_M_B_converter(enterprice_value)

    return float(enterprice_value)

def get_price_to_sales_ratio(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS/key-statistics"
    data = pd.read_html(url)
    price_to_sales_ratio = data[0].at[5,1]
    price_to_sales_ratio = price_to_sales_ratio.replace(",","")

    return float(price_to_sales_ratio)

def get_price_to_book_ratio(stock):
    url = f"https://in.finance.yahoo.com/quote/{stock}.NS/key-statistics"
    data = pd.read_html(url)
    price_to_book_ratio = data[0].at[6,1]
    price_to_book_ratio = price_to_book_ratio.replace(",","")

    return float(price_to_book_ratio)     





from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'NSE stock data'

# Setting up
setup(
    name="nsestockdata",
    version=VERSION,
    author="Vikram Ahuja",
    author_email="<vikramahuja1313@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['bs4', 'pandas', 'requests'],
    keywords=['python', 'NSE', 'stock','finance', 'data'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
